"""
BMPx Python bindings for D-Bus programming

Constants:
    version              -- current BMPx version
D-Bus
    DBUS_SERVICE         -- service name
    DBUS_PATH            -- service path
    DBUS_INTERFACE       -- service interface
Player
    BMP_STATUS_STOPPED   -- stopped
    BMP_STATUS_PLAYING   -- playing
    BMP_STATUS_PAUSED    -- paused
    BMP_STATUS_CHANGED   -- next/prev

Functions:
    connect()            -- connect to BMPx and return the interface object

Examples:

  import bmpx
  my_bmp = bmpx.connect()
  my_bmp.Play()
  my_bmp.VolumeSet(50)
"""

# current installation bmpx version, for compactibility check
version = (0, 21, 0)


# user should use this library to grab these values which are ALWAYS correct
DBUS_SERVICE = "org.beepmediaplayer.bmp"
DBUS_PATH = "/Core"
DBUS_INTERFACE = "org.beepmediaplayer.bmp"


# play status returned from org.beepmediaplayer.bmp.SetPlayStatus()
BMP_STATUS_STOPPED = 2
BMP_STATUS_PLAYING = 4
BMP_STATUS_PAUSED = 8
BMP_STATUS_CHANGED = 32


def connect():
    """connect()

 Connect to BMPx D-Bus service and return the interface object
    """
    try:
        import dbus
        if getattr(dbus, 'version', (0,0,0)) >= (0,41,0):
            import dbus.glib
    except ImportError, e:
        raise ImportError, 'No suitable D-Bus modules found'

    session_bus = dbus.SessionBus()
    proxy = session_bus.get_object(DBUS_SERVICE, DBUS_PATH)
    interface = dbus.Interface(proxy, DBUS_INTERFACE)
    return interface

